@@ -463,10 +463,13 @@ int nfs3_stat64_async(struct nfs_context *nfs, const char *path,
                       int no_follow, nfs_cb cb, void *private_data);
 int nfs3_statvfs_async(struct nfs_context *nfs, const char *path, nfs_cb cb,
                        void *private_data);
+int nfs3_statvfs64_async(struct nfs_context *nfs, const char *path, nfs_cb cb,
+                         void *private_data);
 int nfs3_symlink_async(struct nfs_context *nfs, const char *oldpath,
                        const char *newpath, nfs_cb cb, void *private_data);
 int nfs3_truncate_async(struct nfs_context *nfs, const char *path,
                         uint64_t length, nfs_cb cb, void *private_data);
+int nfs3_umount_async(struct nfs_context *nfs, nfs_cb cb, void *private_data);
 int nfs3_unlink_async(struct nfs_context *nfs, const char *path, nfs_cb cb,
                       void *private_data);
 int nfs3_utime_async(struct nfs_context *nfs, const char *path,
@@ -540,6 +543,8 @@ int nfs4_stat64_async(struct nfs_context *nfs, const char *path,
                       int no_follow, nfs_cb cb, void *private_data);
 int nfs4_statvfs_async(struct nfs_context *nfs, const char *path, nfs_cb cb,
                        void *private_data);
+int nfs4_statvfs64_async(struct nfs_context *nfs, const char *path, nfs_cb cb,
+                         void *private_data);
 int nfs4_symlink_async(struct nfs_context *nfs, const char *oldpath,
                        const char *newpath, nfs_cb cb, void *private_data);
 int nfs4_truncate_async(struct nfs_context *nfs, const char *path,
