@@ -66,10 +66,15 @@
 #include <sys/sysmacros.h>
 #endif
 
+#ifdef HAVE_SYS_TIME_H
+#include <sys/time.h>
+#endif
+
 #include <errno.h>
 #include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
+#include <time.h>
 #include "slist.h"
 #include "libnfs.h"
 #include "libnfs-raw.h"
@@ -860,6 +865,26 @@ nfs_mount_async(struct nfs_context *nfs, const char *server,
         }
 }
 
+/*
+ * Async call for umounting an nfs share
+ */
+int
+nfs_umount_async(struct nfs_context *nfs, nfs_cb cb, void *private_data)
+{
+	switch (nfs->version) {
+        case NFS_V3:
+                return nfs3_umount_async(nfs, cb, private_data);
+        case NFS_V4:
+                /* umount is a no-op in v4 */
+                (*cb)(0, nfs, NULL, private_data);
+                return 0;
+        default:
+                nfs_set_error(nfs, "%s does not support NFSv%d",
+                              __FUNCTION__, nfs->version);
+                return -1;
+        }
+}
+
 int
 nfs_normalize_path(struct nfs_context *nfs, char *path)
 {
@@ -1466,6 +1491,22 @@ nfs_statvfs_async(struct nfs_context *nfs, const char *path, nfs_cb cb,
         }
 }
 
+int
+nfs_statvfs64_async(struct nfs_context *nfs, const char *path, nfs_cb cb,
+                    void *private_data)
+{
+	switch (nfs->version) {
+        case NFS_V3:
+                return nfs3_statvfs64_async(nfs, path, cb, private_data);
+        case NFS_V4:
+                return nfs4_statvfs64_async(nfs, path, cb, private_data);
+        default:
+                nfs_set_error(nfs, "%s does not support NFSv%d",
+                              __FUNCTION__, nfs->version);
+                return -1;
+        }
+}
+
 int
 nfs_readlink_async(struct nfs_context *nfs, const char *path, nfs_cb cb,
                     void *private_data)
