@@ -86,6 +86,12 @@
 #include "win32_errnowrapper.h"
 #endif
 
+#ifndef MSG_NOSIGNAL
+#if (defined(__APPLE__) && defined(__MACH__))
+#define MSG_NOSIGNAL 0
+#endif
+#endif
+
 static int
 rpc_reconnect_requeue(struct rpc_context *rpc);
 
@@ -93,12 +99,14 @@ static int
 create_socket(int domain, int type, int protocol)
 {
 #ifdef SOCK_CLOEXEC
-	/* Linux-specific extension (since 2.6.27): set the
+#ifdef __linux__
+    /* Linux-specific extension (since 2.6.27): set the
 	   close-on-exec flag on all sockets to avoid leaking file
 	   descriptors to child processes */
 	int fd = socket(domain, type|SOCK_CLOEXEC, protocol);
 	if (fd >= 0 || errno != EINVAL)
 		return fd;
+#endif
 #endif
 
 	return socket(domain, type, protocol);
@@ -589,11 +597,18 @@ rpc_connect_sockaddr_async(struct rpc_context *rpc)
 	}
 
 	if (rpc->old_fd) {
+#if !defined(WIN32)
 		if (dup2(rpc->fd, rpc->old_fd) == -1) {
 			return -1;
 		}
 		close(rpc->fd);
 		rpc->fd = rpc->old_fd;
+#else
+		/* On Windows dup2 does not work on sockets
+		 * instead just close the old socket */
+		close(rpc->old_fd);
+		rpc->old_fd = 0;
+#endif
 	}
 
 	/* Some systems allow you to set capabilities on an executable
